@@ -1,6 +1,6 @@
 """AskUI Vision Agent"""
 
-__version__ = "0.10.4"
+__version__ = "0.14.0"
 
 from .agent import VisionAgent
 from .locators import Locator
@@ -25,6 +25,7 @@ from .models import (
     OnMessageCb,
     OnMessageCbParam,
     Point,
+    PointList,
     TextBlockParam,
     TextCitationParam,
     ToolResultBlockParam,
@@ -36,7 +37,8 @@ from .models.shared.tools import Tool
 from .models.types.response_schemas import ResponseSchema, ResponseSchemaBase
 from .retry import ConfigurableRetry, Retry
 from .tools import ModifierKey, PcKey
-from .utils.image_utils import ImageSource, Img
+from .utils.image_utils import ImageSource
+from .utils.source_utils import InputSource
 
 try:
     from .android_agent import AndroidVisionAgent
@@ -66,7 +68,7 @@ __all__ = [
     "GetModel",
     "ImageBlockParam",
     "ImageSource",
-    "Img",
+    "InputSource",
     "LocateModel",
     "Locator",
     "MessageParam",
@@ -82,6 +84,7 @@ __all__ = [
     "OnMessageCbParam",
     "PcKey",
     "Point",
+    "PointList",
     "ResponseSchema",
     "ResponseSchemaBase",
     "Retry",
