@@ -1,6 +1,7 @@
 import time
 import types
 from abc import ABC
+from pathlib import Path
 from typing import Annotated, Optional, Type, overload
 
 from dotenv import load_dotenv
@@ -12,10 +13,11 @@ from askui.locators.locators import Locator
 from askui.models.shared.agent_message_param import MessageParam
 from askui.models.shared.agent_on_message_cb import OnMessageCb
 from askui.models.shared.settings import ActSettings
-from askui.models.shared.tools import Tool
+from askui.models.shared.tools import Tool, ToolCollection
 from askui.tools.agent_os import AgentOs
 from askui.tools.android.agent_os import AndroidAgentOs
-from askui.utils.image_utils import ImageSource, Img
+from askui.utils.image_utils import ImageSource
+from askui.utils.source_utils import InputSource, load_image_source, load_source
 
 from .logger import configure_logging, logger
 from .models import ModelComposition
@@ -26,6 +28,7 @@ from .models.models import (
     ModelName,
     ModelRegistry,
     Point,
+    PointList,
     TotalModelChoice,
 )
 from .models.types.response_schemas import ResponseSchema
@@ -48,7 +51,8 @@ class AgentBase(ABC):  # noqa: B024
         configure_logging(level=log_level)
         self._reporter = reporter
         self._agent_os = agent_os
-        self._tools: list[Tool] = tools or []
+
+        self._tools = tools or []
         self._model_router = self._init_model_router(
             reporter=self._reporter,
             models=models or {},
@@ -108,13 +112,13 @@ class AgentBase(ABC):  # noqa: B024
         }
 
     @telemetry.record_call(exclude={"goal", "on_message", "settings", "tools"})
-    @validate_call
+    @validate_call(config=ConfigDict(arbitrary_types_allowed=True))
     def act(
         self,
         goal: Annotated[str | list[MessageParam], Field(min_length=1)],
         model: str | None = None,
         on_message: OnMessageCb | None = None,
-        tools: list[Tool] | None = None,
+        tools: list[Tool] | ToolCollection | None = None,
         settings: ActSettings | None = None,
     ) -> None:
         """
@@ -131,8 +135,8 @@ class AgentBase(ABC):  # noqa: B024
                 be used for achieving the `goal`.
             on_message (OnMessageCb | None, optional): Callback for new messages. If
                 it returns `None`, stops and does not add the message.
-            tools (list[Tool] | None, optional): The tools for the agent.
-                Defaults to a list of default tools depending on the selected model.
+            tools (list[Tool] | ToolCollection | None, optional): The tools for the
+                agent. Defaults to default tools depending on the selected model.
             settings (AgentSettings | None, optional): The settings for the agent.
                 Defaults to a default settings depending on the selected model.
 
@@ -168,7 +172,7 @@ class AgentBase(ABC):  # noqa: B024
         )
         model_choice = model or self._model_choice["act"]
         _settings = settings or self._get_default_settings_for_act(model_choice)
-        _tools = tools or self._get_default_tools_for_act(model_choice)
+        _tools = self._build_tools(tools, model_choice)
         self._model_router.act(
             messages=messages,
             model_choice=model_choice,
@@ -177,6 +181,16 @@ class AgentBase(ABC):  # noqa: B024
             tools=_tools,
         )
 
+    def _build_tools(
+        self, tools: list[Tool] | ToolCollection | None, model_choice: str
+    ) -> ToolCollection:
+        default_tools = self._get_default_tools_for_act(model_choice)
+        if isinstance(tools, list):
+            return ToolCollection(tools=default_tools + tools)
+        if isinstance(tools, ToolCollection):
+            return ToolCollection(default_tools) + tools
+        return ToolCollection(tools=default_tools)
+
     def _get_default_settings_for_act(self, model_choice: str) -> ActSettings:  # noqa: ARG002
         return ActSettings()
 
@@ -189,7 +203,7 @@ class AgentBase(ABC):  # noqa: B024
         query: Annotated[str, Field(min_length=1)],
         response_schema: None = None,
         model: str | None = None,
-        image: Optional[Img] = None,
+        source: Optional[InputSource] = None,
     ) -> str: ...
     @overload
     def get(
@@ -197,38 +211,46 @@ class AgentBase(ABC):  # noqa: B024
         query: Annotated[str, Field(min_length=1)],
         response_schema: Type[ResponseSchema],
         model: str | None = None,
-        image: Optional[Img] = None,
+        source: Optional[InputSource] = None,
     ) -> ResponseSchema: ...
 
-    @telemetry.record_call(exclude={"query", "image", "response_schema"})
+    @telemetry.record_call(exclude={"query", "source", "response_schema"})
     @validate_call(config=ConfigDict(arbitrary_types_allowed=True))
     def get(
         self,
         query: Annotated[str, Field(min_length=1)],
         response_schema: Type[ResponseSchema] | None = None,
         model: str | None = None,
-        image: Optional[Img] = None,
+        source: Optional[InputSource] = None,
     ) -> ResponseSchema | str:
         """
-        Retrieves information from an image (defaults to a screenshot of the current
-        screen) based on the provided `query`.
+        Retrieves information from an image or PDF based on the provided `query`.
+
+        If no `source` is provided, a screenshot of the current screen is taken.
 
         Args:
             query (str): The query describing what information to retrieve.
-            image (Img | None, optional): The image to extract information from.
-                Defaults to a screenshot of the current screen. Can be a path to
-                an image file, a PIL Image object or a data URL.
+            source (InputSource | None, optional): The source to extract information
+                from. Can be a path to an image, PDF, or office document file,
+                a PIL Image object or a data URL. Defaults to a screenshot of the
+                current screen.
             response_schema (Type[ResponseSchema] | None, optional): A Pydantic model
                 class that defines the response schema. If not provided, returns a
                 string.
             model (str | None, optional): The composition or name of the model(s) to
                 be used for retrieving information from the screen or image using the
                 `query`. Note: `response_schema` is not supported by all models.
+                PDF processing is only supported for Gemini models hosted on AskUI.
 
         Returns:
             ResponseSchema | str: The extracted information, `str` if no
                 `response_schema` is provided.
 
+        Raises:
+            NotImplementedError: If PDF processing is not supported for the selected
+                model.
+            ValueError: If the `source` is not a valid PDF or image.
+
         Example:
             ```python
             from askui import ResponseSchemaBase, VisionAgent
@@ -253,7 +275,7 @@ class AgentBase(ABC):  # noqa: B024
                 response = agent.get(
                     "What is the current url shown in the url bar?",
                     response_schema=UrlResponse,
-                    image="screenshot.png",
+                    source="screenshot.png",
                 )
                 # Dump whole model
                 print(response.model_dump_json(indent=2))
@@ -268,7 +290,7 @@ class AgentBase(ABC):  # noqa: B024
                 is_login_page = agent.get(
                     "Is this a login page?",
                     response_schema=bool,
-                    image=Image.open("screenshot.png"),
+                    source=Image.open("screenshot.png"),
                 )
                 print(is_login_page)
 
@@ -302,13 +324,34 @@ class AgentBase(ABC):  # noqa: B024
                 while current:
                     print(current.value)
                     current = current.next
+
+                # Get text from PDF
+                text = agent.get(
+                    "Extract all text from the PDF",
+                    source="document.pdf",
+                )
+                print(text)
             ```
         """
         logger.debug("VisionAgent received instruction to get '%s'", query)
-        _image = ImageSource(self._agent_os.screenshot() if image is None else image)
-        self._reporter.add_message("User", f'get: "{query}"', image=_image.root)
+        _source = (
+            ImageSource(self._agent_os.screenshot())
+            if source is None
+            else load_source(source)
+        )
+
+        # Prepare message content with file path if available
+        user_message_content = f'get: "{query}"' + (
+            f" from '{source}'" if isinstance(source, (str, Path)) else ""
+        )
+
+        self._reporter.add_message(
+            "User",
+            user_message_content,
+            image=_source.root if isinstance(_source, ImageSource) else None,
+        )
         response = self._model_router.get(
-            image=_image,
+            source=_source,
             query=query,
             response_schema=response_schema,
             model_choice=model or self._model_choice["get"],
@@ -321,14 +364,15 @@ class AgentBase(ABC):  # noqa: B024
         self._reporter.add_message("Agent", message_content)
         return response
 
+    @validate_call(config=ConfigDict(arbitrary_types_allowed=True))
     def _locate(
         self,
         locator: str | Locator,
-        screenshot: Optional[Img] = None,
+        screenshot: Optional[InputSource] = None,
         model: ModelComposition | str | None = None,
-    ) -> Point:
-        def locate_with_screenshot() -> Point:
-            _screenshot = ImageSource(
+    ) -> PointList:
+        def locate_with_screenshot() -> PointList:
+            _screenshot = load_image_source(
                 self._agent_os.screenshot() if screenshot is None else screenshot
             )
             return self._model_router.locate(
@@ -337,28 +381,29 @@ class AgentBase(ABC):  # noqa: B024
                 model_choice=model or self._model_choice["locate"],
             )
 
-        point = self._retry.attempt(locate_with_screenshot)
-        self._reporter.add_message("ModelRouter", f"locate: ({point[0]}, {point[1]})")
-        logger.debug("ModelRouter locate: (%d, %d)", point[0], point[1])
-        return point
+        points = self._retry.attempt(locate_with_screenshot)
+        self._reporter.add_message("ModelRouter", f"locate {len(points)} elements")
+        logger.debug("ModelRouter locate: %d elements", len(points))
+        return points
 
     @telemetry.record_call(exclude={"locator", "screenshot"})
     @validate_call(config=ConfigDict(arbitrary_types_allowed=True))
     def locate(
         self,
         locator: str | Locator,
-        screenshot: Optional[Img] = None,
+        screenshot: Optional[InputSource] = None,
         model: ModelComposition | str | None = None,
     ) -> Point:
         """
-        Locates the UI element identified by the provided locator.
+        Locates the first matching UI element identified by the provided locator.
 
         Args:
             locator (str | Locator): The identifier or description of the element to
                 locate.
-            screenshot (Img | None, optional): The screenshot to use for locating the
-                element. Can be a path to an image file, a PIL Image object or a data
-                URL. If `None`, takes a screenshot of the currently selected display.
+            screenshot (InputSource | None, optional): The screenshot to use for
+                locating the element. Can be a path to an image file, a PIL Image object
+                or a data URL. If `None`, takes a screenshot of the currently
+                selected display.
             model (ModelComposition | str | None, optional): The composition or name
                 of the model(s) to be used for locating the element using the `locator`.
 
@@ -374,8 +419,54 @@ class AgentBase(ABC):  # noqa: B024
                 print(f"Element found at coordinates: {point}")
             ```
         """
-        self._reporter.add_message("User", f"locate {locator}")
-        logger.debug("VisionAgent received instruction to locate %s", locator)
+        self._reporter.add_message("User", f"locate first matching element {locator}")
+        logger.debug(
+            "VisionAgent received instruction to locate first matching element %s",
+            locator,
+        )
+        return self._locate(locator, screenshot, model)[0]
+
+    @telemetry.record_call(exclude={"locator", "screenshot"})
+    @validate_call(config=ConfigDict(arbitrary_types_allowed=True))
+    def locate_all(
+        self,
+        locator: str | Locator,
+        screenshot: Optional[InputSource] = None,
+        model: ModelComposition | str | None = None,
+    ) -> PointList:
+        """
+        Locates all matching UI elements identified by the provided locator.
+
+        Note: Some LocateModels can only locate a single element. In this case, the
+        returned list will have a length of 1.
+
+        Args:
+            locator (str | Locator): The identifier or description of the element to
+                locate.
+            screenshot (InputSource | None, optional): The screenshot to use for
+                locating the element. Can be a path to an image file, a PIL Image object
+                or a data URL. If `None`, takes a screenshot of the currently
+                selected display.
+            model (ModelComposition | str | None, optional): The composition or name
+                of the model(s) to be used for locating the element using the `locator`.
+
+        Returns:
+            PointList: The coordinates of the elements as a list of tuples (x, y).
+
+        Example:
+            ```python
+            from askui import VisionAgent
+
+            with VisionAgent() as agent:
+                points = agent.locate_all("Submit button")
+                print(f"Found {len(points)} elements at coordinates: {points}")
+            ```
+        """
+        self._reporter.add_message("User", f"locate all matching UI elements {locator}")
+        logger.debug(
+            "VisionAgent received instruction to locate all matching UI elements %s",
+            locator,
+        )
         return self._locate(locator, screenshot, model)
 
     @telemetry.record_call()
