@@ -1,41 +1,34 @@
 from collections.abc import AsyncGenerator
-from typing import TYPE_CHECKING, Annotated, cast
+from typing import Annotated
 
-from fastapi import APIRouter, Body, HTTPException, Path, Response, status
+from fastapi import APIRouter, BackgroundTasks, Path, Response, status
 from fastapi.responses import JSONResponse, StreamingResponse
 from pydantic import BaseModel
 
-from askui.chat.api.models import ListQueryDep, RunId, ThreadId
-from askui.chat.api.runs.service import CreateRunRequest
+from askui.chat.api.dependencies import ListQueryDep
+from askui.chat.api.models import RunId, ThreadId
+from askui.chat.api.runs.models import RunCreateParams
+from askui.chat.api.threads.dependencies import ThreadFacadeDep
+from askui.chat.api.threads.facade import ThreadFacade
 from askui.utils.api_utils import ListQuery, ListResponse
 
 from .dependencies import RunServiceDep
-from .models import Run
+from .models import Run, ThreadAndRunCreateParams
 from .service import RunService
 
-if TYPE_CHECKING:
-    from .runner.events import Events
+router = APIRouter(tags=["runs"])
 
 
-router = APIRouter(prefix="/threads/{thread_id}/runs", tags=["runs"])
-
-
-@router.post("")
-def create_run(
+@router.post("/threads/{thread_id}/runs")
+async def create_run(
     thread_id: Annotated[ThreadId, Path(...)],
-    request: Annotated[CreateRunRequest, Body(...)],
-    run_service: RunService = RunServiceDep,
+    params: RunCreateParams,
+    background_tasks: BackgroundTasks,
+    thread_facade: ThreadFacade = ThreadFacadeDep,
 ) -> Response:
-    """
-    Create a new run for a given thread.
-    """
-    stream = request.stream
-    run_or_async_generator = run_service.create(thread_id, stream, request)
+    stream = params.stream
+    run, async_generator = await thread_facade.create_run(thread_id, params)
     if stream:
-        async_generator = cast(
-            "AsyncGenerator[Events, None]",
-            run_or_async_generator,
-        )
 
         async def sse_event_stream() -> AsyncGenerator[str, None]:
             async for event in async_generator:
@@ -51,45 +44,70 @@ def create_run(
             content=sse_event_stream(),
             media_type="text/event-stream",
         )
-    run = cast("Run", run_or_async_generator)
+
+    async def _run_async_generator() -> None:
+        async for _ in async_generator:
+            pass
+
+    background_tasks.add_task(_run_async_generator)
     return JSONResponse(status_code=status.HTTP_201_CREATED, content=run.model_dump())
 
 
-@router.get("/{run_id}")
+@router.post("/runs")
+async def create_thread_and_run(
+    params: ThreadAndRunCreateParams,
+    background_tasks: BackgroundTasks,
+    thread_facade: ThreadFacade = ThreadFacadeDep,
+) -> Response:
+    stream = params.stream
+    run, async_generator = await thread_facade.create_thread_and_run(params)
+    if stream:
+
+        async def sse_event_stream() -> AsyncGenerator[str, None]:
+            async for event in async_generator:
+                data = (
+                    event.data.model_dump_json()
+                    if isinstance(event.data, BaseModel)
+                    else event.data
+                )
+                yield f"event: {event.event}\ndata: {data}\n\n"
+
+        return StreamingResponse(
+            status_code=status.HTTP_201_CREATED,
+            content=sse_event_stream(),
+            media_type="text/event-stream",
+        )
+
+    async def _run_async_generator() -> None:
+        async for _ in async_generator:
+            pass
+
+    background_tasks.add_task(_run_async_generator)
+    return JSONResponse(status_code=status.HTTP_201_CREATED, content=run.model_dump())
+
+
+@router.get("/threads/{thread_id}/runs/{run_id}")
 def retrieve_run(
+    thread_id: Annotated[ThreadId, Path(...)],
     run_id: Annotated[RunId, Path(...)],
     run_service: RunService = RunServiceDep,
 ) -> Run:
-    """
-    Retrieve a run by its ID.
-    """
-    try:
-        return run_service.retrieve(run_id)
-    except FileNotFoundError as e:
-        raise HTTPException(status_code=404, detail=str(e)) from e
+    return run_service.retrieve(thread_id, run_id)
 
 
-@router.get("")
+@router.get("/threads/{thread_id}/runs")
 def list_runs(
     thread_id: Annotated[ThreadId, Path(...)],
     query: ListQuery = ListQueryDep,
-    run_service: RunService = RunServiceDep,
+    thread_facade: ThreadFacade = ThreadFacadeDep,
 ) -> ListResponse[Run]:
-    """
-    List runs, optionally filtered by thread.
-    """
-    return run_service.list_(thread_id, query=query)
+    return thread_facade.list_runs(thread_id, query=query)
 
 
-@router.post("/{run_id}/cancel")
+@router.post("/threads/{thread_id}/runs/{run_id}/cancel")
 def cancel_run(
+    thread_id: Annotated[ThreadId, Path(...)],
     run_id: Annotated[RunId, Path(...)],
     run_service: RunService = RunServiceDep,
 ) -> Run:
-    """
-    Cancel a run by its ID.
-    """
-    try:
-        return run_service.cancel(run_id)
-    except FileNotFoundError as e:
-        raise HTTPException(status_code=404, detail=str(e)) from e
+    return run_service.cancel(thread_id, run_id)
