@@ -1,7 +1,6 @@
 import abc
 import re
 from collections.abc import Iterator
-from enum import Enum
 from typing import Annotated, Callable, Type
 
 from pydantic import BaseModel, ConfigDict, Field, RootModel
@@ -11,15 +10,17 @@ from askui.locators.locators import Locator
 from askui.models.shared.agent_message_param import MessageParam
 from askui.models.shared.agent_on_message_cb import OnMessageCb
 from askui.models.shared.settings import ActSettings
-from askui.models.shared.tools import Tool
+from askui.models.shared.tools import ToolCollection
 from askui.models.types.response_schemas import ResponseSchema
 from askui.utils.image_utils import ImageSource
+from askui.utils.source_utils import Source
 
 
-class ModelName(str, Enum):
+class ModelName:
     """Enumeration of all available model names in AskUI.
 
-    This enum provides type-safe access to model identifiers used throughout the
+    This enum is not really an `enum.Enum` but rather a collection of literal strings.
+    It provides type-safe access to model identifiers used throughout the
     library. Each model name corresponds to a specific AI model or model composition
     that can be used for different tasks like acting, getting information, or locating
     elements.
@@ -147,6 +148,11 @@ Point = tuple[int, int]
 A tuple of two integers representing the coordinates of a point on the screen.
 """
 
+PointList = Annotated[list[Point], Field(min_length=1)]
+"""
+A list of points representing the coordinates of elements on the screen.
+"""
+
 
 class ActModel(abc.ABC):
     """Abstract base class for models that can execute autonomous actions.
@@ -185,7 +191,7 @@ class ActModel(abc.ABC):
         messages: list[MessageParam],
         model_choice: str,
         on_message: OnMessageCb | None = None,
-        tools: list[Tool] | None = None,
+        tools: ToolCollection | None = None,
         settings: ActSettings | None = None,
     ) -> None:
         """
@@ -216,7 +222,7 @@ class ActModel(abc.ABC):
                 added to the message history and the acting continues based on the
                 message. The message may be modified by the callback to allow for
                 directing the assistant/agent or tool use.
-            tools (list[Tool] | None, optional): The tools for the agent.
+            tools (ToolCollection | None, optional): The tools for the agent.
                 Defaults to `None`.
             settings (AgentSettings | None, optional): The settings for the agent.
                 Defaults to `None`.
@@ -231,23 +237,22 @@ class ActModel(abc.ABC):
 
 
 class GetModel(abc.ABC):
-    """Abstract base class for models that can extract information from images.
+    """Abstract base class for models that can extract information from images and PDFs.
 
     Models implementing this interface can be used with the `get()` method of
     `VisionAgent`
-    to extract information from screenshots or other images. These models analyze visual
-    content and return structured or unstructured information based on queries.
-
+    to extract information from screenshots, other images or PDFs. These models analyze
+    visual content and return structured or unstructured information based on queries.
     Example:
         ```python
-        from askui import GetModel, VisionAgent, ResponseSchema, ImageSource
+        from askui import GetModel, VisionAgent, ResponseSchema, Source
         from typing import Type
 
         class MyGetModel(GetModel):
             def get(
                 self,
                 query: str,
-                image: ImageSource,
+                source: Source,
                 response_schema: Type[ResponseSchema] | None,
                 model_choice: str,
             ) -> ResponseSchema | str:
@@ -263,15 +268,14 @@ class GetModel(abc.ABC):
     def get(
         self,
         query: str,
-        image: ImageSource,
+        source: Source,
         response_schema: Type[ResponseSchema] | None,
         model_choice: str,
     ) -> ResponseSchema | str:
-        """Extract information from an image based on a query.
-
+        """Extract information from a source based on a query.
         Args:
             query (str): A description of what information to extract
-            image (ImageSource): The image to analyze (screenshot or provided image)
+            source (Source): The source to analyze (screenshot, image or PDF)
             response_schema (Type[ResponseSchema] | None): Optional Pydantic model class
                 defining the expected response structure
             model_choice (str): The name of the model being used (useful for models that
@@ -294,7 +298,7 @@ class LocateModel(abc.ABC):
 
     Example:
         ```python
-        from askui import LocateModel, VisionAgent, Locator, ImageSource, Point
+        from askui import LocateModel, VisionAgent, Locator, ImageSource, PointList
         from askui.models import ModelComposition
 
         class MyLocateModel(LocateModel):
@@ -303,9 +307,9 @@ class LocateModel(abc.ABC):
                 locator: str | Locator,
                 image: ImageSource,
                 model_choice: ModelComposition | str,
-            ) -> Point:
+            ) -> PointList:
                 # Implement custom locate logic
-                return (100, 100)
+                return [(100, 100)]
 
         with VisionAgent(models={"my-locate": MyLocateModel()}) as agent:
             agent.click("button", model="my-locate")
@@ -318,7 +322,7 @@ class LocateModel(abc.ABC):
         locator: str | Locator,
         image: ImageSource,
         model_choice: ModelComposition | str,
-    ) -> Point:
+    ) -> PointList:
         """Find the coordinates of a UI element in an image.
 
         Args:
@@ -329,7 +333,7 @@ class LocateModel(abc.ABC):
                 `ModelComposition` for models that support composition
 
         Returns:
-            A tuple of (x, y) coordinates where the element was found
+            A list of (x, y) coordinates where the element was found, minimum length 1
         """
         raise NotImplementedError
 
