@@ -4,7 +4,6 @@ import httpx
 import pyperclip
 
 from askui.tools.agent_os import AgentOs
-from askui.tools.askui.askui_hub import AskUIHub
 
 
 class AgentToolbox:
@@ -21,22 +20,10 @@ class AgentToolbox:
         clipboard: `pyperclip` module for clipboard access.
         agent_os (AgentOs): The OS interface for mouse, keyboard, and screen actions.
         httpx: HTTPX client for HTTP requests.
-        hub (AskUIHub): Internal AskUI Hub instance.
     """
 
     def __init__(self, agent_os: AgentOs):
         self.webbrowser = webbrowser
         self.clipboard = pyperclip
         self.os = agent_os
-        self._hub = AskUIHub()
         self.httpx = httpx
-
-    @property
-    def hub(self) -> AskUIHub:
-        if self._hub.disabled:
-            error_msg = (
-                "AskUI Hub is disabled. Please, set ASKUI_WORKSPACE_ID and "
-                "ASKUI_TOKEN environment variables to enable it."
-            )
-            raise ValueError(error_msg)
-        return self._hub
